package com.zj365.health.act.healthrecord

import android.graphics.Color
import android.text.TextUtils
import android.util.Log
import android.view.View
import androidx.core.view.get
import androidx.core.view.size
import androidx.core.widget.NestedScrollView
import androidx.recyclerview.widget.LinearLayoutManager
import cn.jpush.android.api.JPushInterface
import com.alibaba.android.arouter.facade.annotation.Route
import com.androidkun.xtablayout.XTabLayout
import com.xty.base.act.BaseVmAct
import com.xty.base.vm.BaseVm
import com.xty.common.Const
import com.xty.common.MMkvHelper
import com.xty.common.R
import com.xty.common.UmengEventId
import com.xty.common.arouter.ARouterUrl
import com.xty.common.arouter.RouteManager
import com.xty.common.onEventObject
import com.xty.common.setImageUser
import com.xty.common.util.CommonUtils
import com.xty.common.util.NumUtils
import com.xty.common.weight.HealthBodyView
import com.xty.network.model.HealthArchiveBean
import com.zj365.health.BuildConfig
import com.zj365.health.adapter.familyhealth.HealthFamilyTargetAdapter
import com.zj365.health.databinding.ActHealthRecordMainBinding
import com.zj365.health.model.MyReportBean
import com.zj365.health.vm.HealthRecordMainVm
import com.zj365.health.vm.ReportVm
import com.zj365.health.weight.HealthSurveyView
import kotlinx.coroutines.GlobalScope
import kotlinx.coroutines.Job
import kotlinx.coroutines.delay
import kotlinx.coroutines.launch

@Route(path = ARouterUrl.FAMILY_RECORD_ACT)
class HealthRecordMainAct : BaseVmAct<HealthRecordMainVm>() {

    val binding by lazy { ActHealthRecordMainBinding.inflate(layoutInflater) }

    val mAdapter by lazy { HealthFamilyTargetAdapter() }


    private val mTitles = mutableListOf<String>()

    private var isSelectTable = false
    private var isScrollTable = false
    private var launch: Job? = null

    var mSurveysList = ArrayList<HealthArchiveBean.SurveysInfoBean>()


    override fun liveObserver() {

        mViewModel.balanceDietBeanLiveData.observe(this){
            binding.tvDietCalorie.text = "${it.data.heat_val}"
            binding.proCho.progress = it.data.cho_percent
            binding.proFat.progress = it.data.fat_percent
            binding.proProtein.progress = it.data.protein_percent
            binding.tvProteinPro.text = "${it.data.protein_percent}%"
            binding.tvFatPro.text = "${it.data.fat_percent}%"
            binding.tvChoPro.text =  "${it.data.cho_percent}%"
        }

        mViewModel.healthArchiveLiveData.observe(this){
            mSurveysList.clear()
            it.data.bmiInfo?.let {
                binding.tvBmi.text = "${it.bmi}"
                binding.tvBmiDesc.text = it.levelName
                if (it.levelName.equals("理想") || it.levelName.equals("标准")){
                    binding.tvBmiDesc.setTextColor(Color.parseColor("#02C191"))
                }
            }

            binding.tvBmr.text = if(it.data.bmr == 0.00) { "--"} else "${it.data.bmr}"
            binding.tvBodyFat.text = if(TextUtils.isEmpty(it.data.bodyFat)) { "--"} else it.data.bodyFat
            binding.mProgress.progress = it.data.userSchedule * 10
            binding.clBody.tvScore.text = "${it.data.surveys.score}"
            mSurveysList = it.data.surveys.list
            binding.tvConfirmTest.visibility = View.GONE
            mSurveysList.forEach {
                if (it.status == 0){
                    binding.tvConfirmTest.visibility = View.VISIBLE
                }
            }
            initSurvey(mSurveysList)
            mAdapter.setNewInstance(it.data.healData)

        }

        mViewModel.settingLive.observe(this) {
            if (null == it.data) return@observe
            it.data.let { settingBean ->

                binding.tvName.text = settingBean.user.name
                if (settingBean.user.avatarUrl.isNullOrEmpty()) {
                    binding.imgAvatar.setImageResource(R.mipmap.icon_default_avator)
                } else {
                    binding.imgAvatar.setImageUser(
                        this,
                        settingBean.user.avatarUrl,
                        settingBean.user.sex.toString()
                    )
                }

                Const.mainLiveData.value = settingBean
            }
        }

    }

    override fun initView() {
        super.initView()
        statusBar(binding.title.mView)
        binding.title.mTvTitle.text ="健康档案"
        binding.title.mIvBack.setOnClickListener {
            finish()
        }



        initTab()
    //    initSurvey()
        initAdapter()
        initClickListener()



    }

    fun initClickListener(){
        binding.llInquiryRecord.setOnClickListener {
            bundle.clear()
            bundle.putString(
                "web_site_url",
                "${BuildConfig.h5url}pages/index/index?pageId=inquiries"
            )
            RouteManager.goAct(ARouterUrl.H5_ACT, bundle)
        }

        binding.tvDairyRecords.setOnClickListener {
            bundle.clear()
            bundle.putString(
                "web_site_url",
                "${BuildConfig.h5url}pages/index/index?pageId=diary"
            )
            RouteManager.goAct(ARouterUrl.H5_ACT, bundle)
        }

        binding.llHealthWeekRecord.setOnClickListener {
            bundle.clear()
           var  showIdInfo =if (MMkvHelper.getLong(Const.USER_ID).toString() == "0") {
                ""
            } else {
                MMkvHelper.getLong(Const.USER_ID).toString()
            }
            bundle.putString("id", showIdInfo)
            bundle.putSerializable("index", ReportVm.ReportInfoType.Week)
            bundle.putBoolean("isDemonstrate", Const.isDemonstrate)
            bundle.putString("titleName", "周报")
            Const.functionListDate.value?.let {
                if(it.size > 0){
                    bundle.putParcelableArrayList("functionList",it)
                }
            }
            RouteManager.goAct(ARouterUrl.HEALTH_WEEK_MONTH_HOUR_REPORT, bundle)
        }

        binding.llReportRecord.setOnClickListener {
            RouteManager.goAct(ARouterUrl.FAMILY_REPORT_LIST_ACT)
        }

        binding.tvCompleteInfo.setOnClickListener {
            RouteManager.goAct(ARouterUrl.BASE_INFO_CHANGE)
        }
    }

    fun initSurvey(surveysList: ArrayList<HealthArchiveBean.SurveysInfoBean>){

        binding.clBody.surveyView.removeAllViews()
        binding.clBody.surveyView.setMenuItemTexts(surveysList)

        binding.clBody.surveyView.setOnClicklisteners(object : HealthSurveyView.onItemClicked{
            override fun onPositionClicked(postion: Int) {
                var bean = mSurveysList[postion]
                bundle.clear()
                bundle.putString("web_site_url","${BuildConfig.url}shareApi/H5_question/${CommonUtils.getMyUserId()}/${bean.surveysId}/android/0")
                bundle.putBoolean("isShowTitle",true)
                bundle.putString("title",bean.name)
                RouteManager.goAct(ARouterUrl.H5_ACT,bundle)
            }
        })
    }

    fun initTab(){
        mTitles.add("自检自测")
        mTitles.add("饮食日记")
        mTitles.add("健康监测")
        mTitles.add("健康记录")

        //设置tab
        mTitles.forEach { tabData ->
            val tab = binding.xTablayout.newTab()
            tab.text = tabData
            binding.xTablayout.addTab(tab)
        }

        binding.xTablayout.setOnTabSelectedListener(object : XTabLayout.OnTabSelectedListener{
            override fun onTabSelected(tab: XTabLayout.Tab) {

                if (!isScrollTable) {
                    isSelectTable = true
                    if (launch != null) {
                        launch?.cancel()
                    }
                    when (mTitles[tab.position]) {
                        "自检自测" -> {
                            binding.scrollView.smoothScrollTo(
                                0,
                                binding.clSelfTest.top
                            )
                        }

                        "饮食日记" -> {
                            binding.scrollView.smoothScrollTo(
                                0,
                                binding.clFoodDiary.top
                            )
                        }

                        "健康监测" -> {
                            binding.scrollView.smoothScrollTo(
                                0,
                                binding.clHealthMonitoring.top
                            )
                        }


                        "健康记录" -> {
                            binding.scrollView.smoothScrollTo(
                                0,
                                binding.clHealthRecording.top
                            )
                        }
                    }

                    launch = GlobalScope.launch {
                        delay(1000) // 延迟一秒
                        // 在这里执行你的操作
                        isSelectTable = false
                    }
                }
            }

            override fun onTabUnselected(tab: XTabLayout.Tab?) {
            }

            override fun onTabReselected(tab: XTabLayout.Tab?) {
            }

        })

        binding.scrollView.setOnScrollChangeListener(NestedScrollView.OnScrollChangeListener { _, _, scrollY, _, _ ->
            if (mTitles.size > 0) {
                if (!isSelectTable) {
                    isScrollTable = true
                    val selectedTabPosition = binding.xTablayout.selectedTabPosition
                    if (scrollY >= binding.clHealthRecording.top) {
                        if (selectedTabPosition != mTitles.size - 1) {
                            binding.xTablayout.getTabAt(mTitles.size - 1)?.select()
                        }
                    } else if (scrollY >= binding.clHealthMonitoring.top) {
                        if (selectedTabPosition != mTitles.size - 2) {
                            binding.xTablayout.getTabAt(mTitles.size - 2)?.select()
                        }
                    } else if (scrollY >= binding.clFoodDiary.top) {
                        if (selectedTabPosition != mTitles.size - 3) {
                            binding.xTablayout.getTabAt(mTitles.size - 3)?.select()
                        }
                    } else if (scrollY >= binding.clSelfTest.top) {
                        if (selectedTabPosition != 0) {
                            binding.xTablayout.getTabAt(0)?.select()
                        }
                    } else {
                        if (selectedTabPosition != 0) {
                            binding.xTablayout.getTabAt(0)?.select()
                            binding.xTablayout.setScrollPosition(0, 0F, true)
                        }
                    }
                    isScrollTable = false
                }
            }
        })
    }

    fun initAdapter (){
        binding.recycler.adapter = mAdapter
        binding.recycler.layoutManager = LinearLayoutManager(this,LinearLayoutManager.HORIZONTAL,false)
    }

    override fun setLayout() = binding.root

    override fun onResume() {
        super.onResume()

        mViewModel.getBalanceDiet()

        mViewModel.getHealthArchive()
        Const.mainLiveData.value?.let {
            binding.tvName.text = it.user.name
            if (it.user.avatarUrl.isNullOrEmpty()) {
                binding.imgAvatar.setImageResource(R.mipmap.icon_default_avator)
            } else {
                binding.imgAvatar.setImageUser(
                    this,
                    it.user.avatarUrl,
                    it.user.sex.toString()
                )
            }

        }
        Const.mainLiveData.value?:mViewModel.getMySetting()
    }
}